import { AwsCredentialIdentityProvider } from "@smithy/types";
import type { FromHttpOptions } from "./fromHttpTypes";
/**
 * Creates a provider that gets credentials via HTTP request.
 */
export declare const fromHttp: (options?: FromHttpOptions) => AwsCredentialIdentityProvider;
