import { Logger } from "@smithy/types";
/**
 * @internal
 *
 * @param url - to be validated.
 * @param logger - passed to CredentialsProviderError.
 * @throws if not acceptable to this provider.
 */
export declare const checkUrl: (url: URL, logger?: Logger) => void;
